@@ -25,6 +25,7 @@ except ImportError:
 import os
 import re
 import subprocess
+import json
 
 from pyparsing import nestedExpr
 
@@ -125,6 +126,44 @@ class AutosubmitConfig(object):
         """
         return self._jobs_parser_file
 
+    def get_full_config_as_dict(self):
+        """
+        Returns full configuration as json object
+        """
+        _conf = _exp = _platforms = _jobs = _proj = None
+        result = {}
+
+        def get_data(parser):
+            """
+            dictionary comprehension to get data from parser
+            """
+            res = {sec: {option: parser.get(sec, option) for option in parser.options(sec)} for sec in [
+                section for section in parser.sections()]}
+            return res
+        # print(self._conf_parser)
+        result["conf"] = get_data(
+            self._conf_parser) if self._conf_parser else None
+        result["exp"] = get_data(
+            self._exp_parser) if self._exp_parser else None
+        result["platforms"] = get_data(
+            self._platforms_parser) if self._platforms_parser else None
+        result["jobs"] = get_data(
+            self._jobs_parser) if self._jobs_parser else None
+        result["proj"] = get_data(
+            self._proj_parser) if self._proj_parser else None
+        return result
+
+    def get_full_config_as_json(self):
+        """
+        Return config as json object
+        """
+        try:
+            return json.dumps(self.get_full_config_as_dict())
+        except Exception as exp:
+            Log.warning(
+                "Autosubmit was not able to retrieve and save the configuration into the historical database.")
+            return ""
+
     def get_project_dir(self):
         """
         Returns experiment's project directory
