@@ -545,6 +545,8 @@ class ExperimentGraphDrawing(MainDataBase):
         );''')
 
         if not os.path.exists(self.database_path):
+            os.umask(0)
+            os.open(self.database_path, os.O_WRONLY | os.O_CREAT, 0o777)
             self.conn = self.create_connection(self.database_path)
             self.create_table()
         else:
@@ -607,8 +609,8 @@ class ExperimentGraphDrawing(MainDataBase):
                     # Logic: Start with 48 as acceptable number of chunks for Gmaxiter = 100
                     # Minimum Gmaxiter will be 10
                     maxiter = max(10, 148 - num_chunks)
-                    print("Experiment {} num_chunk {} maxiter {}".format(
-                        self.expid, num_chunks, maxiter))
+                    # print("Experiment {} num_chunk {} maxiter {}".format(
+                    #     self.expid, num_chunks, maxiter))
                     result = graph.create(
                         ['dot', '-Gnslimit=2', '-Gnslimit1=2', '-Gmaxiter={}'.format(maxiter), '-Gsplines=none', '-v'], format="plain")
                 else:
@@ -937,7 +939,7 @@ class JobDataStructure(MainDataBase):
         else:
             self.conn = self.create_connection(self.database_path)
             self.db_version = self._select_pragma_version()
-            self.query_job_historic = None
+            # self.query_job_historic = None
             # Historic only working on DB 12 now
             self.query_job_historic = "SELECT id, counter, job_name, created, modified, submit, start, finish, status, rowtype, ncpus, wallclock, qos, energy, date, section, member, chunk, last, platform, job_id, extra_data, nnodes, run_id FROM job_data WHERE job_name=? ORDER BY counter DESC"
 
@@ -1230,14 +1232,14 @@ class JobDataStructure(MainDataBase):
                     experiment_run = None
                     # print("{} {}".format(jobdata.rowtype, jobdata.run_id))
                     # ONLY calculate metrics for COMPLETED jobs
+                    if jobdata.run_id is not None:
+                        experiment_run = self.get_experiment_run_by_id(
+                            jobdata.run_id)
                     if jobdata.status == "COMPLETED":
-                        if jobdata.run_id is not None:
-                            experiment_run = self.get_experiment_run_by_id(
-                                jobdata.run_id)
-                            if experiment_run:
-                                years_per_sim = datechunk_to_year(
-                                    experiment_run.chunk_unit, experiment_run.chunk_size)
-                                jobdata.calculateSYPD(years_per_sim)
+                        if experiment_run:
+                            years_per_sim = datechunk_to_year(
+                                experiment_run.chunk_unit, experiment_run.chunk_size)
+                            jobdata.calculateSYPD(years_per_sim)
                         if jobdata.rowtype > 2:
                             package_info = self.get_job_package_info(
                                 jobdata.run_id, jobdata.rowtype)  # get package info
@@ -1262,8 +1264,26 @@ class JobDataStructure(MainDataBase):
                             jobdata.calculateASYPD(
                                 experiment_run.chunk_unit, experiment_run.chunk_size, package_info, average_post_time)
 
-                    result.append({"counter": jobdata.counter, "created": jobdata.created, "submit": jobdata.submit_datetime_str(), "start": jobdata.start_datetime_str(), "finish": jobdata.finish_datetime_str(
-                    ), "queue_time": jobdata.delta_queue_time(job_data_in_package=package_info), "run_time": jobdata.delta_running_time(), "ncpus": jobdata.ncpus, "wallclock": jobdata.wallclock, "qos": jobdata.qos, "platform": jobdata.platform, "job_id": jobdata.job_id, "nodes": jobdata.nnodes, "energy": jobdata.energy_string() if jobdata.run_id is not None and jobdata.energy > 0 else "NA", "status": jobdata.status, "SYPD": jobdata.metric_SYPD, "ASYPD": jobdata.metric_ASYPD, "run_id": jobdata.run_id})
+                    result.append({"counter": jobdata.counter,
+                                   "created": jobdata.created,
+                                   "submit": jobdata.submit_datetime_str(),
+                                   "start": jobdata.start_datetime_str(),
+                                   "finish": jobdata.finish_datetime_str(),
+                                   "queue_time": jobdata.delta_queue_time(job_data_in_package=package_info),
+                                   "run_time": jobdata.delta_running_time(),
+                                   "ncpus": jobdata.ncpus,
+                                   "wallclock": jobdata.wallclock,
+                                   "qos": jobdata.qos,
+                                   "platform": jobdata.platform,
+                                   "job_id": jobdata.job_id,
+                                   "nodes": jobdata.nnodes,
+                                   "energy": jobdata.energy_string() if jobdata.run_id is not None and jobdata.energy > 0 else "NA",
+                                   "status": jobdata.status,
+                                   "SYPD": jobdata.metric_SYPD,
+                                   "ASYPD": jobdata.metric_ASYPD,
+                                   "run_id": jobdata.run_id,
+                                   "run_created": experiment_run.created if experiment_run else "NA"
+                                   })
         except Exception as exp:
             print(traceback.format_exc())
             print(str(exp))
@@ -1297,6 +1317,11 @@ class JobDataStructure(MainDataBase):
         return jobdata
 
     def get_max_id_experiment_run(self):
+        """
+        Get last (max) experiment run object.  
+        :return: ExperimentRun data  
+        :rtype: ExperimentRun object 
+        """
         try:
             # expe = list()
             if os.path.exists(self.database_path) and self.db_version >= DB_VERSION_SCHEMA_CHANGES:
@@ -1617,10 +1642,8 @@ class JobDataStructure(MainDataBase):
             return None
 
     def _get_historic_job_data(self, job_name):
-        """[summary]
+        """
 
-        Args:
-            job_name ([type]): [description]
         """
         try:
             if self.conn:
@@ -1698,11 +1721,11 @@ class JobDataStructure(MainDataBase):
 
     # def _get_experiment_run_ids_from_period(self, period_start):
     #     """
-    #     This function receives period start in timestamp format (int)  
-    #     Then it returns the unique run_id of the jobs that fall in this period.  
-    #     :param period_start: timestamp  
-    #     :type period_start: int   
-    #     :return: 
+    #     This function receives period start in timestamp format (int)
+    #     Then it returns the unique run_id of the jobs that fall in this period.
+    #     :param period_start: timestamp
+    #     :type period_start: int
+    #     :return:
     #     :rtype: list of int
     #     """
     #     try:
