@@ -8,6 +8,7 @@ import traceback
 import sqlite3
 import copy
 from datetime import datetime
+from collections import OrderedDict
 
 DB_FILE_AS_TIMES = "/esarchive/autosubmit/as_times.db"
 DB_FILES_STATUS = "/esarchive/autosubmit/as_metadata/test/status.db"
@@ -263,6 +264,24 @@ def create_many_job_times(conn, list_job):
         #        submit_time, start_time, finish_time, status))
 
 
+def _insert_into_ecearth_details(conn, exp_id, user, created, model, branch, hpc):
+    """
+    Inserts into the details table of ecearth.db  
+    :return: Id  
+    :rtype: int
+    """
+    if conn:
+        try:
+            sql = ''' INSERT INTO details(exp_id, user, created, model, branch, hpc) VALUES(?,?,?,?,?,?) '''
+            cur = conn.cursor()
+            cur.execute(sql, (exp_id, user, created, model, branch, hpc))
+            conn.commit()            
+            return cur.lastrowid
+        except Exception as exp:
+            print(exp)
+    return False
+
+
 def insert_experiment_status(conn, expid, seconds_diff):
     """
     Inserts into table of status if it does not exist and updates status. Requires conn to ecearth.db.\n
@@ -398,6 +417,22 @@ def get_experiment_status():
     return experiment_status
 
 
+def get_currently_running_experiments():
+    """
+    Gets the list of currently running experiments ordered by total_jobs  
+    Connects to AS_TIMES  
+    :return: map of expid -> total_jobs  
+    :rtype: OrderedDict() str -> int
+    """
+    experiment_running = OrderedDict()
+    current_running = _get_exp_only_active()
+    if current_running:
+        for item in current_running:
+            name, status, total_jobs = item
+            experiment_running[name] = total_jobs
+    return experiment_running
+
+
 def get_specific_experiment_status(expid):
     """
     Gets the current status from database.\n
@@ -518,7 +553,7 @@ def get_exps_detailed_complete(conn):
     Get information from details table
     :param conn: ecearth.db connection
     :param expid:
-    :return: Dictionary
+    :return: Dictionary exp_id -> (user, created, model, branch, hpc)
     """
     all_details = _get_exps_detailed_complete(conn)
     result = dict()
@@ -782,6 +817,23 @@ def _get_exp_status():
         return dict()
 
 
+def _get_exp_only_active():
+    """
+    Get all registers of experiments ACTIVE
+    """
+    try:
+        conn = create_connection(DB_FILE_AS_TIMES)
+        conn.text_factory = str
+        cur = conn.cursor()
+        cur.execute("select name, status, total_jobs from currently_running")
+        rows = cur.fetchall()
+        return rows
+    except Exception as exp:
+        print(traceback.format_exc())
+        print(exp)
+        return None
+
+
 def _get_specific_exp_status(expid):
     """
     Get all registers from experiment_status.\n
@@ -893,6 +945,23 @@ def update_exp_status(expid, status, seconds_diff):
         print("Error on Update: " + str(type(e).__name__))
 
 
+def _update_ecearth_details(conn, exp_id, user, created, model, branch, hpc):
+    """
+    Updates ecearth.db table details.
+    """
+    if conn:
+        try:
+            sql = ''' UPDATE details SET user=?, created=?, model=?, branch=?, hpc=? where exp_id=? '''
+            cur = conn.cursor()
+            cur.execute(sql, (user, created, model, branch, hpc, exp_id))
+            conn.commit()
+            return True
+        except Exception as exp:
+            print(exp)
+            return False
+    return False
+
+
 def update_experiment_times(exp_id, modified, completed_jobs, total_jobs, debug=False):
     """
     Update existing experiment times header
