@@ -828,6 +828,8 @@ class Job(object):
     @staticmethod
     def is_a_completed_retrial(fields):
         if len(fields) == 4:
+            if isinstance(fields[0], type(datetime.timedelta())) and isinstance(fields[1], type(datetime.timedelta())) and isinstance(fields[2], type(datetime.timedelta())):
+                return False
             if fields[3] == 'COMPLETED':
                 return True
         return False
