@@ -162,14 +162,15 @@ class SubJobManager(object):
                                     # Add children to root to continue the sequence of fixes
                                     roots.append(
                                         local_index[sub_children_name])
-                                    fix_size = self.subjobindex[sub.name].queue + \
-                                        self.subjobindex[sub.name].run
+                                    fix_size = max(self.subjobindex[sub.name].queue +
+                                                   self.subjobindex[sub.name].run, 0)
                                     # fixes_applied.setdefault(sub_children_name, []).append(fix_size) # If we care about repetition
                                     # Retain the greater fix size
                                     if fix_size > fixes_applied.get(sub_children_name, 0):
                                         fixes_applied[sub_children_name] = fix_size
-                                    fixed_queue_time = self.subjobindex[sub_children_name].queue - fix_size
-                                    new_queues[sub_children_name] = fixed_queue_time if fixed_queue_time >= 0 else 0
+                                    fixed_queue_time = max(
+                                        self.subjobindex[sub_children_name].queue - fix_size, 0)
+                                    new_queues[sub_children_name] = fixed_queue_time
                                     # print(new_queues[sub_name])
 
                 for key, value in new_queues.items():
@@ -200,8 +201,8 @@ class SubJobManager(object):
                             # total time of the previous (next because of reversed for) job by default
                             # Confusing? It is.
                             # Assign to transit the adjusted queue time
-                            filtered[i].transit = filtered[i].queue - \
-                                filtered[i - 1].total
+                            filtered[i].transit = max(filtered[i].queue -
+                                                      filtered[i - 1].total, 0)
 
                         # Positive or zero transit time
                         positive = len(
@@ -213,14 +214,12 @@ class SubJobManager(object):
                                     temp_index = i
                                     if i > 0:
                                         # Only consider after the first job
-                                        filtered[i].queue = (filtered[i].queue -
-                                                             filtered[i - 1].total) if (filtered[i].queue -
-                                                                                        filtered[i - 1].total) >= 0 else 0
+                                        filtered[i].queue = max(filtered[i].queue -
+                                                                filtered[i - 1].total, 0)
                                         fixes_applied[filtered[i].name] = filtered[i - 1].total
                                 else:
-                                    filtered[i].queue = (filtered[i].queue -
-                                                         filtered[temp_index].total) if (filtered[i].queue -
-                                                                                         filtered[temp_index].total) >= 0 else 0
+                                    filtered[i].queue = max(filtered[i].queue -
+                                                            filtered[temp_index].total, 0)
                                     fixes_applied[filtered[i].name] = filtered[temp_index].total
                                 # it is starting of level
 
