@@ -17,11 +17,14 @@
 # You should have received a copy of the GNU General Public License
 # along with Autosubmit.  If not, see <http://www.gnu.org/licenses/>.
 from database.db_common import get_current_running_exp, update_experiment_description_owner
+# Bad practices block starts
 from experiment.common_requests import get_experiment_tree_structured, get_experiment_tree_pkl
 from experiment.common_requests import get_experiment_pkl, get_experiment_stats, test_run, quick_test_run
 from experiment.common_requests import get_experiment_data, get_experiment_graph, get_experiment_run, get_experiment_summary, get_current_status_log_plus
 from experiment.common_requests import get_experiment_metrics, get_quick_view, get_job_history, get_experiment_runs, get_experiment_run_detail, get_experiment_tree_rundetail
-from experiment.common_requests import get_last_test_archive_status, get_job_log, get_experiment_counters
+from experiment.common_requests import get_last_test_archive_status, get_job_log, get_experiment_counters, get_current_configuration_by_expid
+
+# Bad practices block ends
 import experiment.utils as Utiles
 from database.db_common import search_experiment_by_id
 import os
@@ -146,15 +149,49 @@ def update_description():
     app.logger.info('UDESC|RECEIVED|')
     app.logger.info('UDESC|RTIME|' + str(time.time() - start_time))
     return update_experiment_description_owner(expid, new_description, valid_user)
-    # else:
-    #     app.logger.info('UDESC|RECEIVED|')
-    #     app.logger.info('UDESC|RTIME|' + str(time.time() - start_time))
-    #     return {
-    #         'error': True,
-    #         'auth': False,
-    #         'description': None,
-    #         'message': 'Not a valid user'
-    #     }
+
+
+@app.route('/tokentest', methods=['GET', 'POST'])
+@cross_origin(expose_headers="Authorization")
+def test_token():
+    """
+    Tests if a token is still valid
+    """
+    start_time = time.time()
+    current_token = request.headers.get("Authorization")
+    try:
+        jwt_token = jwt.decode(current_token, JWT_SECRET, JWT_ALGORITHM)
+    except Exception as exp:
+        print(exp)
+        jwt_token = {"user_id": None}
+
+    valid_user = jwt_token.get("user_id", None)
+    app.logger.info('TTEST|RECEIVED')
+    app.logger.info('TTEST|RTIME|' + str(time.time() - start_time))
+    return {
+        "isValid": True if valid_user else False,
+        "message": "Session expired" if not valid_user else None
+    }
+
+
+@app.route('/cconfig/<string:expid>', methods=['GET'])
+@cross_origin(expose_headers="Authorization")
+def get_current_configuration(expid):
+    start_time = time.time()
+    current_token = request.headers.get("Authorization")
+    try:
+        jwt_token = jwt.decode(current_token, JWT_SECRET, JWT_ALGORITHM)
+    except Exception as exp:
+        # print(exp)
+        jwt_token = {"user_id": None}
+    valid_user = jwt_token.get("user_id", None)
+    # print(valid_user)
+    app.logger.info('CCONFIG|RECEIVED|' + str(expid))
+    # app.logger.info('Received Query ' + expid)
+    result = get_current_configuration_by_expid(expid, valid_user)
+    app.logger.info('CCONFIG|RTIME|' + str(expid) + "|" +
+                    str(time.time() - start_time))
+    return result
 
 
 @app.route('/expinfo/<string:expid>', methods=['GET'])
@@ -416,11 +453,3 @@ def get_file_status():
     app.logger.info('FSTATUS|RTIME|' + str(time.time() - start_time))
     return result
 
-# @app.route('/group/<string:expid>/<string:groupby>')
-# def get_experiment_grouped(expid, groupby):
-#     app.logger.info("Received Group Request " + expid + " group by " + groupby)
-#     result = get_experiment_graph_grouped(expid, groupby)
-#     return result
-# api.add_resource(Monitor, '/monitor') # Route Monitor
-# if __name__ == '__main__':
-#     app.run(host='0.0.0.0', port='8888')
